atomic_exchange

Function atomic_exchange 

pub fn atomic_exchange(temp: &Path, target: &Path) -> Result<()>
Attempts to atomically exchange the contents of temp and target using XFS_IOC_EXCHANGE_RANGE. This preserves the inode number and hardlinks of target.